@@ -12,7 +12,7 @@ use Bat::Interpreter::Delegate::FileStore::LocalFileSystem;
 use Bat::Interpreter::Delegate::Executor::PartialDryRunner;
 use namespace::autoclean;
 
-our $VERSION = '0.016';    # VERSION
+our $VERSION = '0.017';    # VERSION
 
 # ABSTRACT: Pure perl interpreter for a small subset of bat/cmd files
 
@@ -335,6 +335,8 @@ sub _variable_substitution {
                     $manipulation =~ s/^://;
                     if ( $manipulation =~ /~(?<from>\d+),(?<length>\d+)/ ) {
                         $result = substr( $result, $+{'from'}, $+{'length'} );
+                    } elsif ( $manipulation =~ /~-(?<from_end>\d+),(?<length>\d+)/ ) {
+                        $result = substr( $result, length($result) - $+{'from_end'}, $+{'length'} );
                     } elsif ( $manipulation =~ /\~(\-\d)+/ ) {
                         $result = substr( $result, $1 );
                     }
@@ -405,7 +407,7 @@ Bat::Interpreter - Pure perl interpreter for a small subset of bat/cmd files
 
 =head1 VERSION
 
-version 0.016
+version 0.017
 
 =head1 SYNOPSIS
 
